Facts
=====

.. image:: https://img.shields.io/pypi/v/simplebot_facts.svg
   :target: https://pypi.org/project/simplebot_facts

.. image:: https://img.shields.io/pypi/pyversions/simplebot_facts.svg
   :target: https://pypi.org/project/simplebot_facts

.. image:: https://pepy.tech/badge/simplebot_facts
   :target: https://pepy.tech/project/simplebot_facts

.. image:: https://img.shields.io/pypi/l/simplebot_facts.svg
   :target: https://pypi.org/project/simplebot_facts

.. image:: https://github.com/adbenitez/simplebot_facts/actions/workflows/python-ci.yml/badge.svg
   :target: https://github.com/adbenitez/simplebot_facts/actions/workflows/python-ci.yml

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

A `SimpleBot`_ plugin that allows users to get random facts from https://dailyfacts.org

Install
-------

To install run::

  pip install simplebot-facts


.. _SimpleBot: https://github.com/simplebot-org/simplebot
